@@ -80,6 +80,7 @@ struct _EogScrollViewPrivate {
 	/* actual image */
 	EogImage *image;
 	guint image_changed_id;
+	guint frame_changed_id;
 	GdkPixbuf *pixbuf;
 
 	/* zoom mode, either ZOOM_MODE_FIT or ZOOM_MODE_FREE */
@@ -105,8 +106,11 @@ struct _EogScrollViewPrivate {
 	/* handler ID for paint idle callback */
 	guint idle_id;
 
-	/* Interpolation type */
-	GdkInterpType interp_type;
+	/* Interpolation type when zoomed in*/
+	GdkInterpType interp_type_in;
+
+	/* Interpolation type when zoomed out*/
+	GdkInterpType interp_type_out;
 
 	/* Scroll wheel zoom */
 	gboolean scroll_wheel_zoom;
@@ -159,6 +163,11 @@ free_image_resources (EogScrollView *view)
 		priv->image_changed_id = 0;
 	}
 
+	if (priv->frame_changed_id > 0) {
+		g_signal_handler_disconnect (G_OBJECT (priv->image), priv->frame_changed_id);
+		priv->frame_changed_id = 0;
+	}
+
 	if (priv->image != NULL) {
 		eog_image_data_unref (priv->image);
 		priv->image = NULL;
@@ -246,13 +255,13 @@ update_scrollbar_values (EogScrollView *view)
 
 	priv = view->priv;
 
-	if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (priv->hbar)) && !GTK_WIDGET_VISIBLE (GTK_WIDGET (priv->vbar)))
+	if (!gtk_widget_get_visible (GTK_WIDGET (priv->hbar)) && !gtk_widget_get_visible (GTK_WIDGET (priv->vbar)))
 		return;
 
 	compute_scaled_size (view, priv->zoom, &scaled_width, &scaled_height);
 	allocation = &GTK_WIDGET (priv->display)->allocation;
 
-	if (GTK_WIDGET_VISIBLE (GTK_WIDGET (priv->hbar))) {
+	if (gtk_widget_get_visible (GTK_WIDGET (priv->hbar))) {
 		/* Set scroll increments */
 		priv->hadj->page_size = MIN (scaled_width, allocation->width);
 		priv->hadj->page_increment = allocation->width / 2;
@@ -278,7 +287,7 @@ update_scrollbar_values (EogScrollView *view)
 		}
 	}
 
-	if (GTK_WIDGET_VISIBLE (GTK_WIDGET (priv->vbar))) {
+	if (gtk_widget_get_visible (GTK_WIDGET (priv->vbar))) {
 		priv->vadj->page_size = MIN (scaled_height, allocation->height);
 		priv->vadj->page_increment = allocation->height / 2;
 		priv->vadj->step_increment = SCROLL_STEP_SIZE;
@@ -333,7 +342,7 @@ eog_scroll_view_set_cursor (EogScrollView *view, EogScrollViewCursor new_cursor)
 
 	switch (new_cursor) {
 		case EOG_SCROLL_VIEW_CURSOR_NORMAL:
-			gdk_window_set_cursor (widget->window, NULL);
+			gdk_window_set_cursor (gtk_widget_get_window (widget), NULL);
 			break;
                 case EOG_SCROLL_VIEW_CURSOR_HIDDEN:
                         cursor = eog_scroll_view_create_invisible_cursor ();
@@ -344,7 +353,7 @@ eog_scroll_view_set_cursor (EogScrollView *view, EogScrollViewCursor new_cursor)
 	}
 
 	if (cursor) {
-		gdk_window_set_cursor (widget->window, cursor);
+		gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
 		gdk_cursor_unref (cursor);
 		gdk_flush();
 	}
@@ -408,10 +417,10 @@ check_scrollbar_visibility (EogScrollView *view, GtkAllocation *alloc)
 			hbar_visible = TRUE;
 	}
 
-	if (hbar_visible != GTK_WIDGET_VISIBLE (GTK_WIDGET (priv->hbar)))
+	if (hbar_visible != gtk_widget_get_visible (GTK_WIDGET (priv->hbar)))
 		g_object_set (G_OBJECT (priv->hbar), "visible", hbar_visible, NULL);
 
-	if (vbar_visible != GTK_WIDGET_VISIBLE (GTK_WIDGET (priv->vbar)))
+	if (vbar_visible != gtk_widget_get_visible (GTK_WIDGET (priv->vbar)))
 		g_object_set (G_OBJECT (priv->vbar), "visible", vbar_visible, NULL);
 }
 
@@ -428,6 +437,26 @@ is_unity_zoom (EogScrollView *view)
 	return DOUBLE_EQUAL (priv->zoom, 1.0);
 }
 
+/* Returns whether the image is zoomed in */
+static gboolean
+is_zoomed_in (EogScrollView *view)
+{
+	EogScrollViewPrivate *priv;
+
+	priv = view->priv;
+	return priv->zoom - 1.0 > DOUBLE_EQUAL_MAX_DIFF;
+}
+
+/* Returns whether the image is zoomed out */
+static gboolean
+is_zoomed_out (EogScrollView *view)
+{
+	EogScrollViewPrivate *priv;
+
+	priv = view->priv;
+	return DOUBLE_EQUAL_MAX_DIFF + priv->zoom - 1.0 < 0.0;
+}
+
 /* Returns wether the image is movable, that means if it is larger then
  * the actual visible area.
  */
@@ -438,7 +467,7 @@ is_image_movable (EogScrollView *view)
 
 	priv = view->priv;
 
-	return (GTK_WIDGET_VISIBLE (priv->hbar) || GTK_WIDGET_VISIBLE (priv->vbar));
+	return (gtk_widget_get_visible (priv->hbar) || gtk_widget_get_visible (priv->vbar));
 }
 
 
@@ -501,7 +530,7 @@ paint_background (EogScrollView *view, EogIRect *r, EogIRect *rect)
 
 	eog_irect_intersect (&d, r, rect);
 	if (!eog_irect_empty (&d)) {
-		gdk_window_clear_area (GTK_WIDGET (priv->display)->window,
+		gdk_window_clear_area (gtk_widget_get_window (priv->display),
 				       d.x0, d.y0,
 				       d.x1 - d.x0, d.y1 - d.y0);
 	}
@@ -524,7 +553,7 @@ paint_rectangle (EogScrollView *view, EogIRect *rect, GdkInterpType interp_type)
 
 	priv = view->priv;
 
-	if (!GTK_WIDGET_DRAWABLE (priv->display))
+	if (!gtk_widget_is_drawable (priv->display))
 		return;
 
 	compute_scaled_size (view, priv->zoom, &scaled_width, &scaled_height);
@@ -641,8 +670,8 @@ paint_rectangle (EogScrollView *view, EogIRect *rect, GdkInterpType interp_type)
 			  + (d.y0 - yofs) * rowstride
 			  + 3 * (d.x0 - xofs));
 
-		gdk_draw_rgb_image_dithalign (GTK_WIDGET (priv->display)->window,
-					      GTK_WIDGET (priv->display)->style->black_gc,
+		gdk_draw_rgb_image_dithalign (gtk_widget_get_window (GTK_WIDGET (priv->display)),
+					      gtk_widget_get_style (GTK_WIDGET (priv->display))->black_gc,
 					      d.x0, d.y0,
 					      d.x1 - d.x0, d.y1 - d.y0,
 					      GDK_RGB_DITHER_MAX,
@@ -665,7 +694,7 @@ paint_rectangle (EogScrollView *view, EogIRect *rect, GdkInterpType interp_type)
 	/* Compute transparency parameters */
 	switch (priv->transp_style) {
 	case EOG_TRANSP_BACKGROUND: {
-		GdkColor color = GTK_WIDGET (priv->display)->style->bg[GTK_STATE_NORMAL];
+		GdkColor color = gtk_widget_get_style (GTK_WIDGET (priv->display))->bg[GTK_STATE_NORMAL];
 
 		check_1 = check_2 = (((color.red & 0xff00) << 8)
 				     | (color.green & 0xff00)
@@ -700,8 +729,8 @@ paint_rectangle (EogScrollView *view, EogIRect *rect, GdkInterpType interp_type)
 				    check_size,
 				    check_1, check_2);
 
-	gdk_draw_rgb_image_dithalign (GTK_WIDGET (priv->display)->window,
-				      GTK_WIDGET (priv->display)->style->black_gc,
+	gdk_draw_rgb_image_dithalign (gtk_widget_get_window (priv->display),
+				      gtk_widget_get_style (priv->display)->black_gc,
 				      d.x0, d.y0,
 				      d.x1 - d.x0, d.y1 - d.y0,
 				      GDK_RGB_DITHER_MAX,
@@ -734,9 +763,15 @@ paint_iteration_idle (gpointer data)
 	if (eog_irect_empty (&rect)) {
 		eog_uta_free (priv->uta);
 		priv->uta = NULL;
-	} else
-		paint_rectangle (view, &rect, priv->interp_type);
-
+	} else {
+		if (is_zoomed_in (view))
+			paint_rectangle (view, &rect, priv->interp_type_in);
+		else if (is_zoomed_out (view))
+			paint_rectangle (view, &rect, priv->interp_type_out);
+		else
+			paint_rectangle (view, &rect, GDK_INTERP_NEAREST);
+	}
+		
 	if (!priv->uta) {
 		priv->idle_id = 0;
 		return FALSE;
@@ -760,7 +795,7 @@ request_paint_area (EogScrollView *view, GdkRectangle *area)
 	eog_debug_message (DEBUG_WINDOW, "x: %i, y: %i, width: %i, height: %i\n",
 			   area->x, area->y, area->width, area->height);
 
-	if (!GTK_WIDGET_DRAWABLE (priv->display))
+	if (!gtk_widget_is_drawable (priv->display))
 		return;
 
 	r.x0 = MAX (0, area->x);
@@ -774,7 +809,8 @@ request_paint_area (EogScrollView *view, GdkRectangle *area)
 		return;
 
 	/* Do nearest neighbor, 1:1 zoom or active progressive loading synchronously for speed.  */
-	if (priv->interp_type == GDK_INTERP_NEAREST ||
+	if ((is_zoomed_in (view) && priv->interp_type_in == GDK_INTERP_NEAREST) ||
+	    (is_zoomed_out (view) && priv->interp_type_out == GDK_INTERP_NEAREST) ||
 	    is_unity_zoom (view) ||
 	    priv->progressive_state == PROGRESSIVE_LOADING) {
 		paint_rectangle (view, &r, GDK_INTERP_NEAREST);
@@ -786,8 +822,9 @@ request_paint_area (EogScrollView *view, GdkRectangle *area)
 		 * It's sufficient to add only a antitaliased idle update
 		 */
 		priv->progressive_state = PROGRESSIVE_NONE;
-	else
-		/* do nearest neigbor before anti aliased version */
+	else if (!priv->image || !eog_image_is_animation (priv->image))
+		/* do nearest neigbor before anti aliased version,
+		   except for animations to avoid a "blinking" effect. */
 		paint_rectangle (view, &r, GDK_INTERP_NEAREST);
 
 	/* All other interpolation types are delayed.  */
@@ -824,13 +861,13 @@ scroll_to (EogScrollView *view, int x, int y, gboolean change_adjustments)
 	priv = view->priv;
 
 	/* Check bounds & Compute offsets */
-	if (GTK_WIDGET_VISIBLE (priv->hbar)) {
+	if (gtk_widget_get_visible (priv->hbar)) {
 		x = CLAMP (x, 0, priv->hadj->upper - priv->hadj->page_size);
 		xofs = x - priv->xofs;
 	} else
 		xofs = 0;
 
-	if (GTK_WIDGET_VISIBLE (priv->vbar)) {
+	if (gtk_widget_get_visible (priv->vbar)) {
 		y = CLAMP (y, 0, priv->vadj->upper - priv->vadj->page_size);
 		yofs = y - priv->yofs;
 	} else
@@ -842,7 +879,7 @@ scroll_to (EogScrollView *view, int x, int y, gboolean change_adjustments)
 	priv->xofs = x;
 	priv->yofs = y;
 
-	if (!GTK_WIDGET_DRAWABLE (priv->display))
+	if (!gtk_widget_is_drawable (priv->display))
 		goto out;
 
 	width = GTK_WIDGET (priv->display)->allocation.width;
@@ -853,7 +890,7 @@ scroll_to (EogScrollView *view, int x, int y, gboolean change_adjustments)
 		goto out;
 	}
 
-	window = GTK_WIDGET (priv->display)->window;
+	window = gtk_widget_get_window (GTK_WIDGET (priv->display));
 
 	/* Ensure that the uta has the full size */
 
@@ -1192,7 +1229,8 @@ display_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	if (do_zoom) {
 		gint x, y;
 
-		gdk_window_get_pointer (widget->window, &x, &y, NULL);
+		gdk_window_get_pointer (gtk_widget_get_window (widget),
+					&x, &y, NULL);
 		set_zoom (view, zoom, TRUE, x, y);
 	}
 
@@ -1213,7 +1251,7 @@ eog_scroll_view_button_press_event (GtkWidget *widget, GdkEventButton *event, gp
 	view = EOG_SCROLL_VIEW (data);
 	priv = view->priv;
 
-	if (!GTK_WIDGET_HAS_FOCUS (priv->display))
+	if (!gtk_widget_has_focus (priv->display))
 		gtk_widget_grab_focus (GTK_WIDGET (priv->display));
 
 	if (priv->dragging)
@@ -1375,7 +1413,7 @@ eog_scroll_view_motion_event (GtkWidget *widget, GdkEventMotion *event, gpointer
 		return FALSE;
 
 	if (event->is_hint)
-		gdk_window_get_pointer (GTK_WIDGET (priv->display)->window, &x, &y, &mods);
+		gdk_window_get_pointer (gtk_widget_get_window (GTK_WIDGET (priv->display)), &x, &y, &mods);
 	else {
 		x = event->x;
 		y = event->y;
@@ -1664,7 +1702,7 @@ eog_scroll_view_set_zoom_upscale (EogScrollView *view, gboolean upscale)
 }
 
 void
-eog_scroll_view_set_antialiasing (EogScrollView *view, gboolean state)
+eog_scroll_view_set_antialiasing_in (EogScrollView *view, gboolean state)
 {
 	EogScrollViewPrivate *priv;
 	GdkInterpType new_interp_type;
@@ -1675,8 +1713,26 @@ eog_scroll_view_set_antialiasing (EogScrollView *view, gboolean state)
 
 	new_interp_type = state ? GDK_INTERP_BILINEAR : GDK_INTERP_NEAREST;
 
-	if (priv->interp_type != new_interp_type) {
-		priv->interp_type = new_interp_type;
+	if (priv->interp_type_in != new_interp_type) {
+		priv->interp_type_in = new_interp_type;
+		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+	}
+}
+
+void
+eog_scroll_view_set_antialiasing_out (EogScrollView *view, gboolean state)
+{
+	EogScrollViewPrivate *priv;
+	GdkInterpType new_interp_type;
+
+	g_return_if_fail (EOG_IS_SCROLL_VIEW (view));
+
+	priv = view->priv;
+
+	new_interp_type = state ? GDK_INTERP_BILINEAR : GDK_INTERP_NEAREST;
+
+	if (priv->interp_type_out != new_interp_type) {
+		priv->interp_type_out = new_interp_type;
 		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
 	}
 }
@@ -1840,6 +1896,27 @@ eog_scroll_view_get_zoom_is_max (EogScrollView *view)
 	return DOUBLE_EQUAL (view->priv->zoom, MAX_ZOOM_FACTOR);
 }
 
+static void
+display_next_frame_cb (EogImage *image, gint delay, gpointer data)
+{
+ 	EogScrollViewPrivate *priv;
+	EogScrollView *view;
+
+	if (!EOG_IS_SCROLL_VIEW (data))
+		return;
+
+	view = EOG_SCROLL_VIEW (data);
+	priv = view->priv;
+
+	if (priv->pixbuf != NULL) {
+		g_object_unref (priv->pixbuf);
+		priv->pixbuf = NULL;
+	}
+
+	priv->pixbuf = eog_image_get_pixbuf (image);
+	gtk_widget_queue_draw (GTK_WIDGET (priv->display)); 
+}
+
 void
 eog_scroll_view_set_image (EogScrollView *view, EogImage *image)
 {
@@ -1855,8 +1932,8 @@ eog_scroll_view_set_image (EogScrollView *view, EogImage *image)
 
 	if (priv->image != NULL) {
 		free_image_resources (view);
-		if (GTK_WIDGET_DRAWABLE (priv->display) && image == NULL) {
-			gdk_window_clear (GTK_WIDGET (priv->display)->window);
+		if (gtk_widget_is_drawable (priv->display) && image == NULL) {
+			gdk_window_clear (gtk_widget_get_window (priv->display));
 		}
 	}
 	g_assert (priv->image == NULL);
@@ -1874,8 +1951,8 @@ eog_scroll_view_set_image (EogScrollView *view, EogImage *image)
 			gtk_widget_queue_draw (GTK_WIDGET (priv->display));
 
 		}
-		else if (priv->interp_type != GDK_INTERP_NEAREST &&
-			 !is_unity_zoom (view))
+		else if ((is_zoomed_in (view) && priv->interp_type_in != GDK_INTERP_NEAREST) ||
+			 (is_zoomed_out (view) && priv->interp_type_out != GDK_INTERP_NEAREST))
 		{
 			/* paint antialiased image version */
 			priv->progressive_state = PROGRESSIVE_POLISHING;
@@ -1884,6 +1961,11 @@ eog_scroll_view_set_image (EogScrollView *view, EogImage *image)
 
 		priv->image_changed_id = g_signal_connect (image, "changed",
 							   (GCallback) image_changed_cb, view);
+		if (eog_image_is_animation (image) == TRUE ) {
+			eog_image_start_animation (image);
+			priv->frame_changed_id = g_signal_connect (image, "next-frame", 
+								    (GCallback) display_next_frame_cb, view);
+		}
 	}
 
 	priv->image = image;
@@ -1892,8 +1974,8 @@ eog_scroll_view_set_image (EogScrollView *view, EogImage *image)
 gboolean
 eog_scroll_view_scrollbars_visible (EogScrollView *view)
 {
-	if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (view->priv->hbar)) &&
-	    !GTK_WIDGET_VISIBLE (GTK_WIDGET (view->priv->vbar)))
+	if (!gtk_widget_get_visible (GTK_WIDGET (view->priv->hbar)) &&
+	    !gtk_widget_get_visible (GTK_WIDGET (view->priv->vbar)))
 		return FALSE;
 
 	return TRUE;
@@ -1916,7 +1998,8 @@ eog_scroll_view_init (EogScrollView *view)
 	priv->zoom_mode = ZOOM_MODE_FIT;
 	priv->upscale = FALSE;
 	priv->uta = NULL;
-	priv->interp_type = GDK_INTERP_BILINEAR;
+	priv->interp_type_in = GDK_INTERP_BILINEAR;
+	priv->interp_type_out = GDK_INTERP_BILINEAR;
 	priv->scroll_wheel_zoom = FALSE;
 	priv->zoom_multiplier = IMAGE_VIEW_ZOOM_MULTIPLIER;
 	priv->image = NULL;
